==> gbsite-1.1.1.tar.gz: gbsite/templates/gb/gb_homepage.php <==
<? include("press.php"); ?>
<table cellpadding="2" cellspacing="0" border="0" width="100%">
<tr>
<td width="100%" colspan="3">
<img src="<?= $image_path ?>/home_header5.gif" width="400" height="83" alt="Experience the world's most advanced open source database" border="0">
<center><hr width="100%" size="1" noshade></center>
</td>          
</tr>
<tr>
<td colspan="3"><img src="<?= $image_path ?>/shim.gif" width="1" height="5"></td>
</tr>
<tr>
<td valign="top" width="100%">
	<table cellpadding="2" cellspacing="0" border="0" width="100%">
	<tr>
	<td valign="top"><a href="/product/prodgbpgsql.php"><img src="<?= $image_path ?>/gbpgsql_box.gif" width="100" height="127" border="0"></a></td>
	<td width="100%" valign="top">
		<table cellpadding="2" cellspacing="0" border="0" width="100%">
		<tr bgcolor="<?= $color_6 ?>">
		<td colspan="2"><font face="<?= $font_1 ?>" size="2" color="<?= $color_2 ?>"><b>Now Available:</b></font></td>
		</tr>
		<tr>
		<td colspan="2"><font face="<?= $font_1 ?>" size="2"><b>Great Bridge PostgreSQL for Linux</b></font><br><br></td>
		</tr>
		<tr>
		<td valign="top"><img src="<?= $image_path ?>/home_bullet.gif" width="15" height="15"></td>
		<td><font face="<?= $font_1 ?>" size="2">An enhanced QA-tested distribution of the open source PostgreSQL database</font><br><br></td>
		</tr>
		<tr>
		<td valign="top"><img src="<?= $image_path ?>/home_bullet.gif" width="15" height="15"></td>
		<td><font face="<?= $font_1 ?>" size="2">A suite of technical support packages designed to meet the diverse needs of database users</font><br><br></td>
		</tr>
		<tr>
		<td valign="top"><img src="<?= $image_path ?>/home_bullet.gif" width="15" height="15"></td>
		<td><font face="<?= $font_1 ?>" size="2">And professional consulting services to help application builders harness the power of PostgreSQL</font><br><br> </td>
		</tr>
		<tr>
		<td colspan="2"><font face="<?= $font_1 ?>" size="2">Learn more about <a href="/product/prodgbpgsql.php">Great Bridge PostgreSQL</a>.</font></td>
		</tr>
		</table>
	</td>
	</tr>
	<tr>
	<td colspan="2" align="center"><hr width="100%" size="1" noshade></td>
	</tr>
	<tr>
	<td colspan="2"><img src="<?= $image_path ?>/shim.gif" width="1" height="5"></td>
	</tr>	
	<tr>
	<td valign="top"><a href="http://www2.linuxjournal.com/advertising/Press/2000ec_winners.html" target="_blank"><img src="<?= $image_path ?>/linuxjournal-mag.gif" width="79" height="41" border="0"></a></td>
	<td valign="top">
	<font face="<?= $font_1 ?>" size="2" color="<?= $color_1 ?>">
	<b>2000 Editor's choice awards - </b> PostgreSQL was recently selected as Best Database by the editors of <i>Linux Journal</i>, beating proprietary and open source database offerings alike<br>... <a href="http://www2.linuxjournal.com/advertising/Press/2000ec_winners.html" target="_blank">More here</a>
	</font>
	</td>
	</tr>
	<tr>
	<td colspan="2" align="center"><hr width="100%" size="1" noshade></td>
	</tr>
	<tr>
	<td valign="top"><img src="<?= $image_path ?>/pgsqlbook.gif" width="108" height="134" border="0"></td>
	<td valign="top"><font face="<?= $font_1 ?>" size="2" color="<?= $color_1 ?>"><b>PostgreSQL: Introduction and Concepts.</b> A new book by Great Bridge's Bruce Momijan, a founding member of the PostgreSQL Global Development Group. Click <a href="/genpage?pgbook">here</a> to order.</font></td>
	</tr>
	</table>
</td>
<!-- spacer -->
<td><img src="<?= $image_path ?>/shim.gif" width="10" height="1"></td>
<!-- news -->
<td valign="top" bgcolor="<?= $color_4 ?>">
<img src="<?= $image_path ?>/shim.gif" width="120" height="1"><br>
<font face="<?= $font_1 ?>" size="2"><b>Great Bridge News</b></font><br>
	<table cellspacing="1" cellpadding="2" border="0" bgcolor="<?= $color_2 ?>" width="100%">
	<?if(is_array($press_list)) {
           reset ($press_list); 
      while(list(,$rel) = @each($press_list)) {
	    if (empty($rel["url"])) {
                $link = "/about/press.php?content_id=" . $rel["content_id"] ;
                $target = "";
	    } else {
                $link = $rel["url"];
                $target = " target=_blank";
            }
	?> 
	<tr>
	<td>
	<font face="<?= $font_1 ?>" size="2">
	<i><b><?= date("n/j/Y",strtotime($rel["submit_date"])) ?></b></i>
	<br>
	<b><?= $rel["slug"] ?></b>
	<br>
	<?= substr($rel["title"],0,200) ?>...
	<p align="right"><font face="<?= $font_1 ?>" size="2"><a href="<?= $link ?>"<?= $target ?>><i><?= $rel["author"] ?></i></a></font></p>
	</font>
	</td>
	</tr>
	<? }
         }  ?>
	</table>
</td>
</tr>
</table>

==> gbsite-2.0.0.tar.gz: gbsite/templates/gb/gb_homepage.php <==
<? include("press.php"); ?>
<table cellpadding="2" cellspacing="0" border="0" width="100%">
<tr>
<td width="100%" colspan="3">
<img src="<?= $image_path ?>/home_header5.gif" width="400" height="83" alt="Experience the world's most advanced open source database" border="0">
<center><hr width="100%" size="1" noshade></center>
</td>          
</tr>
<tr>
<td colspan="3"><img src="<?= $image_path ?>/shim.gif" width="1" height="5"></td>
</tr>
<tr>
<td valign="top" width="100%">
	<table cellpadding="2" cellspacing="0" border="0" width="100%">
	<tr>
	<td valign="top"><a href="/product/prodgbpgsql.php"><img src="<?= $image_path ?>/gbpgsql_box.gif" width="100" height="127" border="0"></a></td>
	<td width="100%" valign="top">
		<table cellpadding="2" cellspacing="0" border="0" width="100%">
		<tr bgcolor="<?= $color_6 ?>">
		<td colspan="2"><font face="<?= $font_1 ?>" size="2" color="<?= $color_2 ?>"><b>Now Available:</b></font></td>
		</tr>
		<tr>
		<td colspan="2"><font face="<?= $font_1 ?>" size="2"><b>Great Bridge PostgreSQL for Linux</b></font><br><br></td>
		</tr>
		<tr>
		<td valign="top"><img src="<?= $image_path ?>/home_bullet.gif" width="15" height="15"></td>
		<td><font face="<?= $font_1 ?>" size="2">An enhanced QA-tested distribution of the open source PostgreSQL database</font><br><br></td>
		</tr>
		<tr>
		<td valign="top"><img src="<?= $image_path ?>/home_bullet.gif" width="15" height="15"></td>
		<td><font face="<?= $font_1 ?>" size="2">A suite of technical support packages designed to meet the diverse needs of database users</font><br><br></td>
		</tr>
		<tr>
		<td valign="top"><img src="<?= $image_path ?>/home_bullet.gif" width="15" height="15"></td>
		<td><font face="<?= $font_1 ?>" size="2">And professional consulting services to help application builders harness the power of PostgreSQL</font><br><br> </td>
		</tr>
		<tr>
		<td colspan="2"><font face="<?= $font_1 ?>" size="2">Learn more about <a href="/product/prodgbpgsql.php">Great Bridge PostgreSQL</a>.</font></td>
		</tr>
		</table>
	</td>
	</tr>
	<tr>
	<td><img src="<?= $image_path ?>/shim.gif" width="1" height="5"></td>
	</tr>
	<tr>
	<td colspan="2" align="center"><hr width="100%" size="1" noshade></td>
	</tr>
	<tr>
	<td valign="top"  align="center"><a href="/download/pgsol.php"><img src="<?= $image_path ?>/pgsol.gif" width="123" height="39" border="0"></a></td>
	<td valign="top">
	<font face="<?= $font_1 ?>" size="2" color="<?= $color_1 ?>">
	<b>PostgreSQL on Solaris - </b> A new open source project sponsored by Great Bridge, providing simple package-based installation of the world's most advanced open source database for Solaris users. Click <a href="/download/pgsol.php">here</a> for more.
	</font>
	</td>
	</tr>
	<tr>
	<td colspan="2" align="center"><hr width="100%" size="1" noshade></td>
	</tr>
	<tr>
	<td valign="top"  align="center"><a href="http://www2.linuxjournal.com/advertising/Press/2000ec_winners.html" target="_blank"><img src="<?= $image_path ?>/linuxjournal-mag.gif" width="79" height="41" border="0"></a></td>
	<td valign="top">
	<font face="<?= $font_1 ?>" size="2" color="<?= $color_1 ?>">
	<b>2000 Editor's choice awards - </b> PostgreSQL was recently selected as Best Database by the editors of <i>Linux Journal</i>, beating proprietary and open source database offerings alike<br>... <a href="http://www2.linuxjournal.com/advertising/Press/2000ec_winners.html" target="_blank">More here</a>
	</font>
	</td>
	</tr>
	<tr>
	<td colspan="2" align="center"><hr width="100%" size="1" noshade></td>
	</tr>
	<tr>
	<td valign="top" align="center"><img src="<?= $image_path ?>/pgsqlbook.gif" width="108" height="134" border="0"></td>
	<td valign="top"><font face="<?= $font_1 ?>" size="2" color="<?= $color_1 ?>"><b>PostgreSQL: Introduction and Concepts.</b> A new book by Great Bridge's Bruce Momijan, a founding member of the PostgreSQL Global Development Group. Click <a href="/genpage?pgbook">here</a> to order.</font></td>
	</tr>
	</table>
</td>
<!-- spacer -->
<td><img src="<?= $image_path ?>/shim.gif" width="10" height="1"></td>
<!-- news -->
<td valign="top" bgcolor="<?= $color_4 ?>">
<img src="<?= $image_path ?>/shim.gif" width="120" height="1"><br>
<font face="<?= $font_1 ?>" size="2"><b>Great Bridge News</b></font><br>
	<table cellspacing="1" cellpadding="2" border="0" bgcolor="<?= $color_2 ?>" width="100%">
	<?if(is_array($press_list)) {
           reset ($press_list); 
      while(list(,$rel) = @each($press_list)) {
	    if (empty($rel["url"])) {
                $link = "/about/press.php?content_id=" . $rel["content_id"] ;
                $target = "";
	    } else {
                $link = $rel["url"];
                $target = " target=_blank";
            }
	?> 
	<tr>
	<td>
	<font face="<?= $font_1 ?>" size="2">
	<i><b><?= date("n/j/Y",strtotime($rel["submit_date"])) ?></b></i>
	<br>
	<b><?= $rel["slug"] ?></b>
	<br>
	<?= substr($rel["title"],0,200) ?>...
	<p align="right"><font face="<?= $font_1 ?>" size="2"><a href="<?= $link ?>"<?= $target ?>><i><?= $rel["author"] ?></i></a></font></p>
	</font>
	</td>
	</tr>
	<? }
         }  ?>
	</table>
</td>
</tr>
</table>
